@@ -50,7 +50,7 @@ class Fdfs_client(object):
         self.trackers = trackers
         self.tracker_pool = poolclass(**self.trackers)
         self.timeout = self.trackers['timeout']
-        return None
+        self.appender_ret_obj = None
 
     def __del__(self):
         try:
@@ -627,6 +627,7 @@ class Fdfs_client(object):
         :param chunk_size: 分片大小
         :return:
         """
+        self.appender_ret_obj = None
         assert isinstance(filename, str), 'filename should be str type.'
         if not os.path.isfile(filename):
             raise FDFSError('It is not a file %s' % filename)
@@ -646,7 +647,7 @@ class Fdfs_client(object):
             buffer = fin.read(chunk_size)
             while buffer:
                 try:
-                    self.append_by_buffer(buffer, remote_fileid)
+                    self.appender_ret_obj = self.append_by_buffer(buffer, remote_fileid)
                     # todo 若fin.read 报错，则会导致文件上传错误。
                     buffer = fin.read(chunk_size)
                 except Exception as e:
